package App::freq ;  
our $VERSION = '0.126' ; 
our $DATE = '2024-03-16T00:06+09:00' ; 

=encoding utf8

=head1 NAME

App::freq - `freq' command counts how many different content of each line appears, with various options.

入力を読み取り、各行の文字列が、同じ内容で何回現れたか頻度を数えて、集計表にする。

=head1 SYNOPSIS

This module provides a Unix-like command `F<freq>'. 
The function is similar to `sort | uniq -c' also with many useful functions.

=head1 DESCRIPTION

=head1 SEE ALSO

=head1 AUTHOR

下野寿之 Toshiyuki SHIMONO <bin4tsv@gmail.com> Waseda University

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2016-2024 Toshiyuki SHIMONO. All rights reserved.
This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut

1 ;
